# Person

Type: object

##

Type: string

The person's first name.

##

Type: string

The person's last name.

##

## Pattern Property

All property whose name matches the following regular expression must respect the following conditions

Property name regular expression: `$[a-c][0-9]^`
Type: object

Review of a paper size.

##

Type: integer

Numerical rating for paper size.

##

Type: string

Narrative review of the paper size.